@@ -1,7 +1,6 @@
-/* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * dhcpcd - DHCP client daemon
- * Copyright (c) 2006-2021 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2018 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -38,9 +37,13 @@
 
 #include <ifaddrs.h>
 
-/* If the interface does not support carrier status (ie PPP),
- * dhcpcd can poll it for the relevant flags periodically */
-#define IF_POLL_UP	100	/* milliseconds */
+/* Some systems have in-built IPv4 DAD.
+ * However, we need them to do DAD at carrier up as well. */
+#ifdef IN_IFF_TENTATIVE
+#  ifdef __NetBSD__
+#    define NOCARRIER_PRESERVE_IP
+#  endif
+#endif
 
 /*
  * Systems which handle 1 address per alias.
@@ -58,16 +61,6 @@
 #endif
 
 #include "config.h"
-
-/* POSIX defines ioctl request as an int, which Solaris and musl use.
- * Everyone else use an unsigned long, which happens to be the bigger one
- * so we use that in our on wire API. */
-#ifdef IOCTL_REQUEST_TYPE
-typedef IOCTL_REQUEST_TYPE	ioctl_request_t;
-#else
-typedef unsigned long		ioctl_request_t;
-#endif
-
 #include "dhcpcd.h"
 #include "ipv4.h"
 #include "ipv6.h"
@@ -86,13 +79,6 @@ typedef unsigned long		ioctl_request_t;
 #  define ARPHRD_INFINIBAND		32
 #endif
 
-/* Maximum frame length.
- * Support jumbo frames and some extra. */
-#define	FRAMEHDRLEN_MAX			14	/* only ethernet support */
-#define	FRAMELEN_MAX			(FRAMEHDRLEN_MAX + 9216)
-
-#define UDPLEN_MAX			64 * 1024
-
 /* Work out if we have a private address or not
  * 10/8
  * 172.16/12
@@ -104,6 +90,9 @@ typedef unsigned long		ioctl_request_t;
 	    ((addr & IN_CLASSB_NET) == 0xc0a80000))
 #endif
 
+#define RAW_EOF			1 << 0
+#define RAW_PARTIALCSUM		2 << 0
+
 #ifndef CLLADDR
 #ifdef AF_LINK
 #  define CLLADDR(sdl) (const void *)((sdl)->sdl_data + (sdl)->sdl_nlen)
@@ -115,51 +104,28 @@ typedef unsigned long		ioctl_request_t;
  * but then ignores it. */
 #undef RTF_CLONING
 
-/* This interface is busted on DilOS at least.
- * It used to work, but lukily Solaris can fall back to
- * IP_PKTINFO. */
-#undef IP_RECVIF
-
 /* Solaris getifaddrs is very un-suitable for dhcpcd.
  * See if-sun.c for details why. */
 struct ifaddrs;
 int if_getifaddrs(struct ifaddrs **);
 #define	getifaddrs	if_getifaddrs
-int if_getsubnet(struct dhcpcd_ctx *, const char *, int, void *, size_t);
 #endif
 
-int if_ioctl(struct dhcpcd_ctx *, ioctl_request_t, void *, size_t);
-#ifdef HAVE_PLEDGE
-#define	pioctl(ctx, req, data, len) if_ioctl((ctx), (req), (data), (len))
-#else
-#define	pioctl(ctx, req, data, len) ioctl((ctx)->pf_inet_fd, (req),(data),(len))
-#endif
-int if_getflags(struct interface *);
-int if_setflag(struct interface *, short, short);
-#define if_up(ifp) if_setflag((ifp), (IFF_UP | IFF_RUNNING), 0)
-#define if_down(ifp) if_setflag((ifp), 0, IFF_UP);
-bool if_is_link_up(const struct interface *);
+int if_setflag(struct interface *ifp, short flag);
+#define if_up(ifp) if_setflag((ifp), (IFF_UP | IFF_RUNNING))
 bool if_valid_hwaddr(const uint8_t *, size_t);
 struct if_head *if_discover(struct dhcpcd_ctx *, struct ifaddrs **,
     int, char * const *);
-void if_markaddrsstale(struct if_head *);
 void if_learnaddrs(struct dhcpcd_ctx *, struct if_head *, struct ifaddrs **);
-void if_deletestaleaddrs(struct if_head *);
 struct interface *if_find(struct if_head *, const char *);
 struct interface *if_findindex(struct if_head *, unsigned int);
 struct interface *if_loopback(struct dhcpcd_ctx *);
+void if_sortinterfaces(struct dhcpcd_ctx *);
 void if_free(struct interface *);
 int if_domtu(const struct interface *, short int);
 #define if_getmtu(ifp) if_domtu((ifp), 0)
 #define if_setmtu(ifp, mtu) if_domtu((ifp), (mtu))
-int if_carrier(struct interface *, const void *);
-bool if_roaming(struct interface *);
-
-#ifdef ALIAS_ADDR
-int if_makealias(char *, size_t, const char *, int);
-#endif
-
-int if_mtu_os(const struct interface *);
+int if_carrier(struct interface *);
 
 /*
  * Helper to decode an interface name of bge0:1 to
@@ -171,28 +137,21 @@ struct if_spec {
 	char devname[IF_NAMESIZE];
 	char drvname[IF_NAMESIZE];
 	int ppa;
-	int vlid;
 	int lun;
 };
 int if_nametospec(const char *, struct if_spec *);
 
 /* The below functions are provided by if-KERNEL.c */
-int os_init(void);
 int if_conf(struct interface *);
 int if_init(struct interface *);
 int if_getssid(struct interface *);
-int if_ignoregroup(int, const char *);
-bool if_ignore(struct dhcpcd_ctx *, const char *);
-int if_vimaster(struct dhcpcd_ctx *ctx, const char *);
+int if_vimaster(const struct dhcpcd_ctx *ctx, const char *);
 unsigned short if_vlanid(const struct interface *);
-char * if_getnetworknamespace(char *, size_t);
 int if_opensockets(struct dhcpcd_ctx *);
 int if_opensockets_os(struct dhcpcd_ctx *);
 void if_closesockets(struct dhcpcd_ctx *);
 void if_closesockets_os(struct dhcpcd_ctx *);
 int if_handlelink(struct dhcpcd_ctx *);
-int if_randomisemac(struct interface *);
-int if_setmac(struct interface *ifp, void *, uint8_t);
 
 /* dhcpcd uses the same routing flags as BSD.
  * If the platform doesn't use these flags,
@@ -216,17 +175,9 @@ int if_setmac(struct interface *ifp, void *, uint8_t);
 #else
 # define SOCK_NONBLOCK	0x20000000
 #endif
-#ifndef SOCK_CXNB
-#define	SOCK_CXNB	SOCK_CLOEXEC | SOCK_NONBLOCK
-#endif
-int xsocket(int, int, int);
-int xsocketpair(int, int, int, int[2]);
 
 int if_route(unsigned char, const struct rt *rt);
-int if_initrt(struct dhcpcd_ctx *, rb_tree_t *, int);
-
-int if_missfilter(struct interface *, struct sockaddr *);
-int if_missfilter_apply(struct dhcpcd_ctx *);
+int if_initrt(struct dhcpcd_ctx *, int);
 
 #ifdef INET
 int if_address(unsigned char, const struct ipv4_addr *);
@@ -236,14 +187,15 @@ int if_addrflags(const struct interface *, const struct in_addr *,
 #endif
 
 #ifdef INET6
-void if_disable_rtadv(void);
-void if_setup_inet6(const struct interface *);
-int ip6_forwarding(const char *ifname);
+int if_checkipv6(struct dhcpcd_ctx *ctx, const struct interface *);
+#ifdef IPV6_MANAGETEMPADDR
+int ip6_use_tempaddr(const char *ifname);
+int ip6_temp_preferred_lifetime(const char *ifname);
+int ip6_temp_valid_lifetime(const char *ifname);
+#else
+#define ip6_use_tempaddr(a) (0)
+#endif
 
-struct ra;
-struct ipv6_addr;
-
-int if_applyra(const struct ra *);
 int if_address6(unsigned char, const struct ipv6_addr *);
 int if_addrflags6(const struct interface *, const struct in6_addr *,
     const char *);
@@ -254,12 +206,5 @@ int if_getlifetime6(struct ipv6_addr *);
 #endif
 
 int if_machinearch(char *, size_t);
-struct interface *if_findifpfromcmsg(struct dhcpcd_ctx *,
-    struct msghdr *, int *);
-
-#ifdef __linux__
-int if_linksocket(struct sockaddr_nl *, int, int);
-int if_getnetlink(struct dhcpcd_ctx *, struct iovec *, int, int,
-    int (*)(struct dhcpcd_ctx *, void *, struct nlmsghdr *), void *);
-#endif
+int xsocket(int, int, int);
 #endif
