@@ -1,7 +1,6 @@
-/* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * dhcpcd - DHCP client daemon
- * Copyright (c) 2006-2021 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2018 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -41,15 +40,12 @@
 #include "arp.h"
 
 struct ipv4ll_state {
-	struct in_addr pickedaddr;
 	struct ipv4_addr *addr;
-	char randomstate[128];
-	bool seeded;
-	bool down;
-	size_t conflicts;
-#ifndef KERNEL_RFC5227
 	struct arp_state *arp;
-#endif
+	unsigned int conflicts;
+	struct timespec defend;
+	char randomstate[128];
+	uint8_t down;
 };
 
 #define	IPV4LL_STATE(ifp)						       \
@@ -60,20 +56,26 @@ struct ipv4ll_state {
 	(IPV4LL_CSTATE((ifp)) && !IPV4LL_CSTATE((ifp))->down &&		       \
 	(IPV4LL_CSTATE((ifp))->addr != NULL))
 
-int ipv4ll_subnetroute(rb_tree_t *, struct interface *);
-int ipv4ll_defaultroute(rb_tree_t *,struct interface *);
-ssize_t ipv4ll_env(FILE *, const char *, const struct interface *);
+int ipv4ll_subnetroute(struct rt_head *, struct interface *);
+int ipv4ll_defaultroute(struct rt_head *,struct interface *);
+ssize_t ipv4ll_env(char **, const char *, const struct interface *);
 void ipv4ll_start(void *);
 void ipv4ll_claimed(void *);
 void ipv4ll_handle_failure(void *);
-struct ipv4_addr *ipv4ll_handleifa(int, struct ipv4_addr *, pid_t pid);
 #ifdef HAVE_ROUTE_METRIC
 int ipv4ll_recvrt(int, const struct rt *);
 #endif
 
-void ipv4ll_reset(struct interface *);
-void ipv4ll_drop(struct interface *);
-void ipv4ll_free(struct interface *);
+#define	ipv4ll_free(ifp)		ipv4ll_freedrop((ifp), 0);
+#define	ipv4ll_drop(ifp)		ipv4ll_freedrop((ifp), 1);
+void ipv4ll_freedrop(struct interface *, int);
+#else
+#define	IPV4LL_STATE_RUNNING(ifp)	(0)
+#define	ipv4ll_subnetroute(route, ifp)	(0)
+#define	ipv4ll_defaultroute(route, ifp)	(0)
+#define	ipv4ll_handlert(a, b, c)	(0)
+#define	ipv4ll_free(a)			{}
+#define	ipv4ll_drop(a)			{}
 #endif
 
 #endif
